<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Resource\Model\TranslationInterface;

/**
 * @ORM\Entity()
 * @ORM\Table(name="dedi_blog_type_article")
 */
class TypeArticle extends AbstractReferable implements TypeArticleInterface
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     * @ORM\Column(type="integer", nullable=false, name="id")
     */
    private ?int $id;

    /** @ORM\Column(type="string", nullable=false, name="type_article_code", unique=true) */
    protected ?string $code = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        /** @var TypeArticleTranslationInterface $translation */
        $translation = $this->getTranslation();

        return $translation->getName();
    }

    public function setName(string $name): self
    {
        /** @var TypeArticleTranslationInterface $translation */
        $translation = $this->getTranslation();
        $translation->setName($name);

        return $this;
    }

    public function getTranslation(?string $locale = null): AbstractReferableTranslation
    {
        /** @var TypeArticleTranslation $translation */
        $translation = parent::getTranslation($locale);

        return $translation;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(?string $code): self
    {
        $this->code = $code;

        return $this;
    }

    protected function createTranslation(): TranslationInterface
    {
        return new TypeArticleTranslation();
    }

    public function __toString(): string
    {
        return $this->getName();
    }
}
